@@ -1,7 +1,7 @@
 package Graphics::Primitive;
 use Moose;
 
-our $VERSION = '0.44';
+our $VERSION = '0.45';
 
 __PACKAGE__->meta->make_immutable;
 
@@ -87,8 +87,6 @@ L<CSS|http://www.w3.org/Style/CSS/>'s box model.
 
 Cory Watson, C<< <gphat@cpan.org> >>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 ACKNOWLEDGEMENTS
 
 Many of the ideas here come from my experience using the Cairo library.
@@ -101,9 +99,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
