@@ -182,13 +182,9 @@ Count of paths saved in I<saved_paths>.
 
 Cory Watson <gphat@cpan.org>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 You can redistribute and/or modify this code under the same terms as Perl
 itself.
\ No newline at end of file
