@@ -241,9 +241,7 @@ removed.>  Returns an arrayref of Components that were removed.
 
 =head1 AUTHOR
 
-Cory Watson, C<< <gphat@cpan.org> >>
-
-Infinity Interactive, L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 =head1 BUGS
 
@@ -253,9 +251,7 @@ automatically be notified of progress on your bug as I make changes.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
\ No newline at end of file
